@@ -27,6 +27,7 @@
 #' library("DALEX")
 #' library("randomForest")
 #'
+#' \donttest{
 #' model_titanic_rf <- randomForest(survived ~.,  data = titanic_imputed)
 #'
 #' explain_titanic_rf <- explain(model_titanic_rf,
@@ -39,7 +40,7 @@
 #'
 #' plot(cp_rf, variable_type = "categorical")
 #' describe(cp_rf, variables = "class", label = "the predicted probability")
-#'
+#' }
 #' @export
 #' @rdname describe
 describe <- function(x, ...)
@@ -268,7 +269,11 @@ describe_ceteris_paribus_continuous <- function(x,
   max_name <- df[which.max(df$`_yhat_`), variables]
   min_name <- df[which.min(df$`_yhat_`), variables]
   cutpoint <- find_optimal_cutpoint_average(smooth(df$`_yhat_`))
-  cut_name <- round(df[cutpoint, variables], 3)
+  # do not round if it's below minimum #76
+  cut_name <- max(
+    round(df[cutpoint, variables], 3),
+    min(c(df[, variables])) # never get smaller than min
+  )
 
   # Test if the break point is between max_name and min_name
   multiple_breakpoints <- ifelse((cut_name < min(min_name, max_name) | cut_name > max(min_name, max_name)),
