@@ -17,6 +17,9 @@
 #' @param show_boxplots logical if \code{TRUE} (default) boxplot will be plotted to show permutation data.
 #' @param bar_width width of bars. By default \code{10}
 #' @param desc_sorting logical. Should the bars be sorted descending? By default TRUE
+#' @param title the plot's title, by default \code{'Feature Importance'}
+#' @param subtitle the plot's subtitle. By default - NA, which means
+#' the subtitle will be 'created for the XXX model', where XXX is the label of explainer(s)
 #'
 #' @importFrom stats model.frame reorder
 #' @importFrom utils head tail
@@ -57,7 +60,7 @@
 #' explainer_rf  <- explain(HR_rf_model, data = HR, y = HR$status,
 #'                          verbose = FALSE, precalculate = FALSE)
 #'
-#' fi_rf <- feature_importance(explainer_rf, type = "raw",
+#' fi_rf <- feature_importance(explainer_rf, type = "raw", max_vars = 3,
 #'                             loss_function = loss_cross_entropy)
 #' head(fi_rf)
 #' plot(fi_rf)
@@ -90,9 +93,10 @@
 #' }
 #'
 #' @export
-plot.feature_importance_explainer <- function(x, ..., max_vars = NULL, show_boxplots = TRUE, bar_width = 10, desc_sorting = TRUE) {
+plot.feature_importance_explainer <- function(x, ..., max_vars = NULL, show_boxplots = TRUE, bar_width = 10,
+                                              desc_sorting = TRUE, title = "Feature Importance", subtitle = NA) {
 
-  if (!is.logical(desc_sorting)){
+  if (!is.logical(desc_sorting)) {
     stop("desc_sorting is not logical")
   }
 
@@ -143,13 +147,19 @@ plot.feature_importance_explainer <- function(x, ..., max_vars = NULL, show_boxp
     trimmed_parts <- lapply(unique(ext_expl_df$label), function(label) {
       tmp <- ext_expl_df[ext_expl_df$label == label, ]
       tmp[tail(order(tmp$dropout_loss.x), max_vars), ]
-    });
+    })
     ext_expl_df <- do.call(rbind, trimmed_parts)
-  };
+  }
 
   variable <- q1 <- q3 <- dropout_loss.x <- dropout_loss.y <- label <- dropout_loss <- NULL
   nlabels <- length(unique(bestFits$label))
 
+  # extract labels for plot's subtitle
+  if (is.na(subtitle)) {
+    glm_labels <- paste0(unique(ext_expl_df$label), collapse = ", ")
+    subtitle <- paste0("created for the ", glm_labels, " model")
+  }
+
   # plot it
   pl <- ggplot(ext_expl_df, aes(variable, ymin = dropout_loss.y, ymax = dropout_loss.x, color = label)) +
           geom_hline(data = bestFits, aes(yintercept = dropout_loss, color = label), lty= 3) +
@@ -166,8 +176,10 @@ plot.feature_importance_explainer <- function(x, ..., max_vars = NULL, show_boxp
   pl + coord_flip() +
       scale_color_manual(values = colors_discrete_drwhy(nlabels)) +
       facet_wrap(~label, ncol = 1, scales = "free_y") + theme_drwhy_vertical() +
-      theme(legend.position = "none") +
-      ylab("Drop-out loss") + xlab("")
+      ylab("Drop-out loss") + xlab("") +
+      labs(title = title, subtitle = subtitle) +
+      theme(legend.position = "none",
+            plot.subtitle = element_text(hjust = 0.5, vjust = 0.15))
 
 }
 
